@@ -171,26 +171,31 @@ class MainWindow(hildon.Program):
 			boton.append(self.button1)
 
 			if distro == 'fremantle':
-				boton[i].set_size_request(80, 20)
+				boton[i].set_size_request(75, 20)
 			else:
 				boton[i].set_size_request(38, 20)
 
 			boton[i].set_border_width(0)
 			boton[i].connect("clicked", self.on_click)
 
-			self.eventbox=gtk.EventBox()
-			self.eventbox.set_size_request(15, 20)
-			caja.append(self.eventbox)
+			#self.eventbox=gtk.EventBox()
+			#self.eventbox.set_size_request(15, 20)
+			#caja.append(self.eventbox)
 
-			boton[i].add(self.eventbox)
+			#boton[i].add(self.eventbox)
 
-			self.eventbox.show()
+			#self.eventbox.show()
 			self.label1 = gtk.Label()
-			self.label1.set_markup("<small>"+sim[i]+"</small>")
-			self.eventbox.add(self.label1)
+			self.label1.set_markup("<b>"+sim[i]+"</b>")
+			#self.eventbox.add(self.label1)
+			boton[i].add(self.label1)
+			caja.append(self.label1)
+
 			self.label1.show()
 			color=elige_color(2,i)
-			self.eventbox.modify_bg(gtk.STATE_NORMAL,self.eventbox.get_colormap().alloc_color(color))
+			self.label1.modify_fg(gtk.STATE_NORMAL,self.label1.get_colormap().alloc_color(color))
+
+			#self.eventbox.modify_bg(gtk.STATE_NORMAL,self.eventbox.get_colormap().alloc_color(color))
 
 
 			boton[i].set_name(sim[i])
@@ -263,7 +268,7 @@ class MainWindow(hildon.Program):
 			self.window.add(self.table1)
 
 	def color_selector(self):
-		selector = hildon.hildon_touch_selector_new_text()
+		selector = hildon.TouchSelector(text=True)
 		data = ["Classic", "Colorless", "Groups", "Phys. State"]
 		for i in range(len(data)):
 			selector.append_text(data[i])
@@ -487,27 +492,27 @@ class MainWindow(hildon.Program):
 
 	def on_view_cless(self, widget):
 		for i in range(1,len(caja)):
-			caja[i].modify_bg(gtk.STATE_NORMAL,caja[i].get_colormap().alloc_color("grey"))
+			caja[i].modify_fg(gtk.STATE_NORMAL,caja[i].get_colormap().alloc_color("grey"))
 			caja[i].show()
 
 
 	def on_view_group(self, widget):
 		for i in range(1,len(caja)):
 			color=elige_color(1,i)
-			caja[i].modify_bg(gtk.STATE_NORMAL,caja[i].get_colormap().alloc_color(color))
+			caja[i].modify_fg(gtk.STATE_NORMAL,caja[i].get_colormap().alloc_color(color))
 			caja[i].show()
 
 	def on_view_classic(self, widget):
 		for i in range(1,len(caja)):
 			color=elige_color(2,i)
-			caja[i].modify_bg(gtk.STATE_NORMAL,caja[i].get_colormap().alloc_color(color))
+			caja[i].modify_fg(gtk.STATE_NORMAL,caja[i].get_colormap().alloc_color(color))
 			caja[i].show()
 
 	def on_view_fisest(self,widget):
 
 		for i in range(1,len(caja)):
 			color=elige_color(3,i)
-			caja[i].modify_bg(gtk.STATE_NORMAL,caja[i].get_colormap().alloc_color(color))
+			caja[i].modify_fg(gtk.STATE_NORMAL,caja[i].get_colormap().alloc_color(color))
 			caja[i].show()
 
 
@@ -561,7 +566,13 @@ class MyDialog(MainWindow):
 
 	def __init__(MainWindow):
 		def show_tab(widget, notebook, number):
-			notebook.set_current_page(number)
+			if distro == 'fremantle':
+				if widget.get_active():
+					notebook.set_current_page(0)
+				else:
+					notebook.set_current_page(1)
+			else:
+				notebook.set_current_page(number)
 
 		def scroll_to(x=0, y=0):
 			v = swin.get_vadjustment()
@@ -579,15 +590,16 @@ class MyDialog(MainWindow):
 # Los valores de 100 y -100 son los 'pixels' que avanza el scroll
 
 		def on_key_press(widget, event, *args):
-			if event.keyval == gtk.keysyms.Down:
-				scroll_by(0, 100)
-			elif event.keyval == gtk.keysyms.Up:
-				scroll_by(0, -100)
-			elif event.keyval == gtk.keysyms.F6:
-				if win.win_in_fullscreen:
-					win.unfullscreen ()
-				else:
-					win.fullscreen ()
+			if not distro == 'fremantle':
+				if event.keyval == gtk.keysyms.Down:
+					scroll_by(0, 100)
+				elif event.keyval == gtk.keysyms.Up:
+					scroll_by(0, -100)
+				elif event.keyval == gtk.keysyms.F6:
+					if win.win_in_fullscreen:
+						win.unfullscreen ()
+					else:
+						win.fullscreen ()
 
 		def on_window_state_change(widget, event, *args):
 			if event.new_window_state & gtk.gdk.WINDOW_STATE_FULLSCREEN:
@@ -609,6 +621,7 @@ class MyDialog(MainWindow):
 		notebook = gtk.Notebook()
 		notebook.set_show_tabs(False)
 		notebook.set_scrollable(False)
+		notebook.set_show_border(False)
 		notebook.show()
 
 		if distro == 'fremantle':
@@ -654,7 +667,7 @@ class MyDialog(MainWindow):
 					trozo.append(resto)
 					etiqueta+="<b>%25s:</b> %s\n" % (tit,trozo[0])
 
-					for i in range(1,len(trozo)): etiqueta+=' '*26+trozo[i]+'\n'
+					for i in range(1,len(trozo)): etiqueta+=' '*27+trozo[i]+'\n'
 
 					#En este caso no hara falta poner unidades
 					#etiqueta+=' '*28+trozo[-1]+unids+'\n'
@@ -678,7 +691,6 @@ class MyDialog(MainWindow):
 		scrolledwindow2 = gtk.ScrolledWindow()
 		scrolledwindow2.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
 		scrolledwindow2.show()
-		scrolledwindow2.set_shadow_type(gtk.SHADOW_IN)
 
 		isot_div = isot[int(num[nelem])].split(",")
 		etiqueta1='<tt>'
@@ -708,18 +720,23 @@ class MyDialog(MainWindow):
 		hbox = gtk.HBox()
 
 		if distro == 'fremantle':
-			button1 = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
-									hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
-			button2 = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
-									hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
-			button1.set_title("Properties")
-			button2.set_title("Isotopes")
+			button1 = hildon.GtkRadioButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+			button1.set_mode(False)
+			button1.set_label("Properties")
+
+			button2 = hildon.GtkRadioButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+			button2.set_mode(False)
+			button2.set_label("Isotopes")
+			button2.set_group(button1)
+
+			button1.set_active(True)
+			button1.connect('toggled', show_tab, notebook, 0)
+
 		else:
 			button1 = gtk.Button("Properties")
 			button2 = gtk.Button("Isotopes")
-
-		button1.connect("clicked", show_tab, notebook, 0)
-		button2.connect("clicked", show_tab, notebook, 1)
+			button1.connect("clicked", show_tab, notebook, 0)
+			button2.connect("clicked", show_tab, notebook, 1)
 
 		hbox.pack_start(button1, True, True, 0)
 		hbox.pack_start(button2, True, True, 0)
@@ -1034,7 +1051,7 @@ class GraficProps(MainWindow):
 			pass
 
 		def create_selector(titulo, graficable):
-			selector = hildon.hildon_touch_selector_new_text()
+			selector = hildon.TouchSelector(text=True)
 			for i in range(len(titulo)):
 				if graficable[i]:
 					selector.append_text(titulo[i])
@@ -1042,7 +1059,7 @@ class GraficProps(MainWindow):
 			return selector
 
 		def create_bselector(sim):
-			selector = hildon.hildon_touch_selector_new_text()
+			selector = hildon.TouchSelector(text=True)
 			for i in range(1,len(sim)):
 				selector.append_text(sim[i])
 
@@ -1067,17 +1084,25 @@ class GraficProps(MainWindow):
 
 		dra1.connect('expose_event',refoco)
 
-		menubar2 = gtk.Menu()
-		for child in menubar2.get_children():
-			child.reparent(menu)
-		wgraf.set_menu(menubar2)
-		menubar2.show()
+		if distro == 'fremantle':
+			menu = hildon.AppMenu()
+			wgraf.set_app_menu(menu)
+			save_menu = gtk.Button("Save")
+			save_menu.connect("clicked", save_png)
+			menu.append(save_menu)
+			menu.show_all()
+		else:
+			menubar2 = gtk.Menu()
+			for child in menubar2.get_children():
+				child.reparent(menu)
+			wgraf.set_menu(menubar2)
+			menubar2.show()
 
-		save_menu = gtk.MenuItem("Save")
-		save_menu.set_size_request(-1, 45)
-		save_menu.show()
-		save_menu.connect("activate", save_png)
-		menubar2.append(save_menu)
+			save_menu = gtk.MenuItem("Save")
+			save_menu.set_size_request(-1, 45)
+			save_menu.show()
+			save_menu.connect("activate", save_png)
+			menubar2.append(save_menu)
 
 		vbox1.pack_start(dra1, True, True,0)
 		hbox1=gtk.HBox(False,0)
@@ -1231,7 +1256,7 @@ class WebConect(MainWindow):
 
 	def __init__(MainWindow):
 		def create_selector():
-			selector = hildon.hildon_touch_selector_new_text()
+			selector = hildon.TouchSelector(text=True)
 			selector.append_text('http://webbook.nist.gov/chemistry/')
 			selector.append_text('http://www.iupac.org/')
 			selector.append_text('http://www.sciencedirect.com/')
